==> estateplat-common-1.2.4-20201110.023611-494-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlDyaqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlDyaq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlDyaqBdc extends QlfQlDyaq {
    private String dfdybdclxdm;
    private String dfdybdclxmc;
    private String dfdyfsdm;
    private String dfdyfsmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    @XmlAttribute(
            name = "DFDYBDCLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdybdclxdm() {
        return dfdybdclxdm;
    }

    public void setDfdybdclxdm(String dfdybdclxdm) {
        this.dfdybdclxdm = dfdybdclxdm;
    }
    @XmlTransient
    public String getDfdybdclxmc() {
        return dfdybdclxmc;
    }

    public void setDfdybdclxmc(String dfdybdclxmc) {
        this.dfdybdclxmc = dfdybdclxmc;
    }
    @XmlAttribute(
            name = "DFDYFSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdyfsdm() {
        return dfdyfsdm;
    }

    public void setDfdyfsdm(String dfdyfsdm) {
        this.dfdyfsdm = dfdyfsdm;
    }
    @XmlTransient
    public String getDfdyfsmc() {
        return dfdyfsmc;
    }

    public void setDfdyfsmc(String dfdyfsmc) {
        this.dfdyfsmc = dfdyfsmc;
    }
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlTransient
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlTransient
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
}

==> estateplat-common-1.2.4-20201112.065422-500-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlDyaqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlDyaq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlDyaqBdc extends QlfQlDyaq {
    private String dfdybdclxdm;
    private String dfdybdclxmc;
    private String dfdyfsdm;
    private String dfdyfsmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    @XmlAttribute(
            name = "DFDYBDCLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdybdclxdm() {
        return dfdybdclxdm;
    }

    public void setDfdybdclxdm(String dfdybdclxdm) {
        this.dfdybdclxdm = dfdybdclxdm;
    }
    @XmlAttribute(
            name = "DFDYBDCLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdybdclxmc() {
        return dfdybdclxmc;
    }

    public void setDfdybdclxmc(String dfdybdclxmc) {
        this.dfdybdclxmc = dfdybdclxmc;
    }
    @XmlAttribute(
            name = "DFDYFSDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdyfsdm() {
        return dfdyfsdm;
    }

    public void setDfdyfsdm(String dfdyfsdm) {
        this.dfdyfsdm = dfdyfsdm;
    }
    @XmlAttribute(
            name = "DFDYFSMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdyfsmc() {
        return dfdyfsmc;
    }

    public void setDfdyfsmc(String dfdyfsmc) {
        this.dfdyfsmc = dfdyfsmc;
    }
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
}
